Name:           iml
Version:        1.0.4
Release:        2%{?dist}
Summary:        Finds solutions to systems of linear equations over integers
Group:          Applications/Engineering
License:        BSD
URL:            https://cs.uwaterloo.ca/~astorjoh/iml.html
Source0:        https://cs.uwaterloo.ca/~astorjoh/%{name}-%{version}.tar.gz

BuildRequires:  atlas-devel
BuildRequires:  gmp-devel


%description
IML provides efficient routines to compute exact solutions to dense
systems of linear equations over the integers.  The following
functionality is provided:
- Nonsingular rational system solving.
- Compute the right nullspace of an integer matrix.
- Certified linear system solving.


%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       atlas-devel%{?_isa}, gmp-devel%{?_isa}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%package        static
Summary:        Static library for %{name}
Group:          Development/Libraries
Requires:       %{name}-devel%{?_isa} = %{version}-%{release}

%description    static
The %{name}-static package contains a static library for %{name}.


%prep
%setup -q

%build
%configure --enable-shared --with-cblas="-lsatlas" \
  --with-cblas-include=%{_includedir}/atlas \
  --with-cblas-lib=%{_libdir}/atlas

# Get rid of undesirable hardcoded rpaths; workaround libtool reordering
# -Wl,--as-needed after all the libraries.
sed -e 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' \
    -e 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' \
    -e 's|CC=.g..|& -Wl,--as-needed|' \
    -i libtool

make %{?_smp_mflags}


%install
make install DESTDIR=$RPM_BUILD_ROOT
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la
rm -fr $RPM_BUILD_ROOT%{_datadir}/%{name}


%check
export LD_LIBRARY_PATH=$PWD/src/.libs
make check


%post -p /sbin/ldconfig


%postun -p /sbin/ldconfig


%files
%doc AUTHORS README
%{_libdir}/lib%{name}.so.*


%files devel
%doc doc/liblink doc/libroutines examples
%{_includedir}/*
%{_libdir}/lib%{name}.so


%files static
%{_libdir}/lib%{name}.a


%changelog
* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Mon Aug  4 2014 Jerry James <loganjerry@gmail.com> - 1.0.4-1
- New upstream release
- All patches and typo fixes have been applied upstream

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.3-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Thu Oct  3 2013 Jerry James <loganjerry@gmail.com> - 1.0.3-8
- Update project and source URLs

* Sat Sep 21 2013 Jerry James <loganjerry@gmail.com> - 1.0.3-7
- Rebuild for atlas 3.10.1

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.3-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue Mar 26 2013 Jerry James <loganjerry@gmail.com> - 1.0.3-5
- Support building on aarch64 (bz 925584)

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat Jan  7 2012 Jerry James <loganjerry@gmail.com> - 1.0.3-2
- Rebuild for GCC 4.7

* Wed Oct 26 2011 Marcela Mašláňová <mmaslano@redhat.com> - 1.0.3-1.1
- rebuild with new gmp

* Tue Apr 26 2011 Jerry James <loganjerry@gmail.com> - 1.0.3-1
- New upstream release
- Fix URL
- Update description from the web site
- Drop BuildRoot tag, clean script, and clean at start of install script
- Move static library into a -static subpackage
- Fix code typo in iml 1.0.3

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.2-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.2-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Conrad Meyer <konrad@tylerc.org> - 1.0.2-6
- Fix FTBFS errors.

* Tue Feb 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.2-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Oct 27 2008 Conrad Meyer <konrad@tylerc.org> - 1.0.2-4
- Oops, don't depend on the main package which no longer exists in -devel.

* Fri Oct 17 2008 Conrad Meyer <konrad@tylerc.org> - 1.0.2-2
- Only generate one binary package.
- Add %%check.

* Sun Oct 12 2008 Conrad Meyer <konrad@tylerc.org> - 1.0.2-1
- Initial package.
